##########################################################################################

##  CITIZENS UNITED, STATES DIVIDED
##  AN EMPIRICAL ANALYSIS OF INDEPENDENT POLITICAL SPENDING

##  Indiana Law Journal, vol. 89, no. 1, pp. 315-372 (2014)

##  Replication code created by Doug Spencer
##  Contact: doug.spencer@law.uconn.edu

##  Last updated: March 1, 2015

##  Mac OSX 10.8.5
##  R version 3.1.2 ('Pumpkin Helmet')

##########################################################################################
## Library in required packages
##########################################################################################

library(foreign)
library(ggplot2)
library(xtable)
library(maps, mapproj, mapdata)
library(lmtest)
library(boot)
library(quantreg)

##########################################################################################
##	Read in data files
##########################################################################################

## Note: We scraped spending data from the NIMSP website with a Python script,
## then subset to independent expenditures, and aggregated by spender.

## Set working directory where data files are saved
setwd('/cusd_replication/')

ie <- read.csv('data/nimsp_ie.csv', head=T, stringsAsFactors=F)
state <- read.csv('data/state_vars.csv', stringsAsFactors=FALSE, head=TRUE)

##########################################################################################
##	Independent variables
##########################################################################################

## Remove states with no gub race and NC for lagged CU problem
ie <- subset(ie, ie$State!='CT' & ie$State!='WI' & ie$State!='NC')

##  Identify FIVE types of races:

#		(1) Gubernatorial races
#		(2) State legislative races
#		(3) State judicial races
#		(4) Ballot initiatives
#		(5) Other statewide offices

## (1) Gubernatorial races (12,428 IEs)
ie$race.type <- rep(0, dim(ie)[1])
ie$race.type[ie$Seat=='GOVERNOR' | ie$Seat=='GOVERNOR / LIEUTENANT GOVERNOR' | ie$Seat=='LIEUTENANT GOVERNOR'] <- 'Governor/Lieutenant Governor'

# (2) State legislative races (40,339 IEs)
ie$race.type[grep('HOUSE', ie$Seat)] <- 'State Legislature'
ie$race.type[grep('SENATE', ie$Seat)] <- 'State Legislature'
ie$race.type[grep('ASSEMBLY', ie$Seat)] <- 'State Legislature'

# (3) State judicial races (1,9172 IEs)
ie$race.type[grep('COURT', ie$Seat)] <- 'Judicial'

# (4) Ballot initiatives (18,041 IEs)
ie$race.type[grep('[a-z]', ie$Seat)] <- 'Ballot Initiative'

# (5) Other statewide offices (2,560 IEs)
ie$race.type[ie$race.type==0] <- 'Other Statewide Offices'

table(ie$Year, ie$race.type)

##########
## Create 'elec.year' variable by race type
##########
ie$elec.year <- rep(0, dim(ie)[1])

## GUBERNATORIAL races: omit states with races in 2008

ie$elec.year[
  ie$race.type=='Governor/Lieutenant Governor' &
    ie$State!='MO' &
    ie$State!='NC' &
    ie$State!='WA' &
    ie$Year <= 2006] <- 2006

ie$elec.year[
  ie$race.type=='Governor/Lieutenant Governor' &
    ie$State!='MO' &
    ie$State!='NC' &
    ie$State!='WA' &
    ie$Year > 2006 &
    ie$Year <= 2010] <- 2010

## STATE LEGISLATIVE races

ie$elec.year[ie$race.type=='State Legislature' & ie$Year <= 2006] <- 2006
ie$elec.year[ie$race.type=='State Legislature' & ie$Year > 2006 & ie$Year <= 2008] <- 2008
ie$elec.year[ie$race.type=='State Legislature' & ie$Year > 2008 & ie$Year <= 2010] <- 2010

## JUDICIAL races (omit Washington 2009)

ie$elec.year[ie$race.type=='Judicial' & ie$State=='WA' & ie$Year==2009] <- NA
ie$elec.year[ie$race.type=='Judicial' & ie$Year <= 2006] <- 2006
ie$elec.year[ie$race.type=='Judicial' & ie$Year > 2006 & ie$Year <= 2008] <- 2008
ie$elec.year[ie$race.type=='Judicial' & ie$Year > 2008 & ie$Year <= 2010] <- 2010

## BALLOT initiatives

ie$elec.year[ie$race.type=='Ballot Initiative' & ie$State=='AZ'] <- NA
ie$elec.year[ie$race.type=='Ballot Initiative' & ie$Year <= 2006] <- 2006
ie$elec.year[ie$race.type=='Ballot Initiative' & ie$Year > 2006 & ie$Year <= 2008] <- 2008
ie$elec.year[ie$race.type=='Ballot Initiative' & ie$Year > 2008 & ie$Year <= 2010] <- 2010

## OTHER statewide offices

ie$elec.year[ie$race.type=='Other Statewide Offices' & ie$Year <= 2006] <- 2006
ie$elec.year[ie$race.type=='Other Statewide Offices' & ie$Year > 2006 & ie$Year <= 2008] <- NA
ie$elec.year[ie$race.type=='Other Statewide Offices' & ie$Year > 2008 & ie$Year <= 2010] <- 2010
ie$elec.year[ie$race.type=='Other Statewide Offices' &
               ie$State!='CA' & ie$State!='MI' & ie$State!='MN' & ie$State!='MO' & ie$State!='OH' & ie$State!='TX'] <- NA

ie$elec.year[ie$elec.year==0] <- NA

table(ie$race.type, ie$elec.year)

## Remove ballot measures because IEs legally permitted everywhere
ie <- ie[ie$Amount > 0 & ie$race.type!='Ballot Initiative',] # 58,707 rows remain

## Create dummy variable for corporate/union ban on IEs

ie$ban <- rep(0, dim(ie)[1])
ie$ban <- ifelse(ie$State=='AK' | ie$State=='AZ' | ie$State=='CO' | ie$State=='IA' | ie$State=='MA' | 
                   ie$State=='MI' | ie$State=='MN' | ie$State=='OH' | ie$State=='OK' | ie$State=='TN' | ie$State=='TX', 1, 0)

ie$prepost <- ifelse(ie$elec.year==2010,1,0)

ftable(ie$race.type, ie$elec.year, ie$ban)

##########################################################################################
##	CLEAN UP SPENDER INFO
##########################################################################################

ie$Spender[
    ie$Spender == 'PEOPLE FOR A BETTER FLORIDA CLOSED' | 
    ie$Spender == 'PEOPLE FOR A BETTER FLORIDA FUND' | 
    ie$Spender == 'PEOPLE FOR A BETTER FLORIDA' 
  ] <- 'PEOPLE FOR A BETTER FLORIDA'

ie$Spender[
    ie$Spender == 'SOUTHERN OKLAHOMA DOCTORS COMMITTTED TO TORT REFORM' | 
    ie$Spender == 'SOUTHERN OKLAHOMA DOCTORS COMMITTED TO TORT REFORM'
  ] <- 'SOUTHERN OKLAHOMA DOCTORS COMMITTED TO TORT REFORM'

## Add variables for sector type
ie$source.type <- 0

ie$source.type[
  ie$Sector1=='General Business' |
  ie$Sector1=='Health' 
    ] <- 'Corporation' # we recode non-corporate business and health below

ie$source.type[
    ie$Sector1=='Labor' |
    ie$Spender=='MISSOURI NATIONAL EDUCATION ASSOCIATION' |
    ie$Spender=='INTERNATIONAL UNION OF OPERATING ENGINEERS'
  ] <- 'Labor'

# Single Issue, first of many

ie$source.type[
    ie$Sector1=='Construction' |
    ie$Sector1 == 'Finance, Insurance & Real Estate' |
    ie$Sector1 == 'Lawyers & Lobbyists' |
    ie$Sector1=='Energy & Natural Resources' |
    ie$Sector1=='Transportation' |
    ie$Sector1=='Communications & Electronics' |
    ie$Sector1=='Agriculture'
  ] <- 'Single Issue'

# Now single issue - starting with those that are 'Health'

ie$source.type[grep('PLANNED PARENTHOOD', ie$Spender)] <- 'Single Issue'
ie$source.type[ie$Spender == 'PLANNED PARENT ADVOCATES OF WISCONSIN'] <- 'Single Issue'

ie$source.type[
    ie$Sector1 == 'Ideology/Single Issue' |
    ie$Spender == 'NARAL PRO CHOICE OHIO'|
    ie$Spender == 'ARIZONA HOSPITAL & HEALTHCARE ASSOCIATION'  |   
    ie$Spender == 'ARIZONA CIVIC VENTURES' | # non-profit think tank                 
    ie$Spender == 'MICHIGAN ORTHOPAEDIC SOCIETY' |
    ie$Spender == 'MINNESOTA HOSPITAL ASSOCIATION' |
    ie$Spender == 'OKLAHOMA MEDICAL ASSOCIATION' |
    ie$Spender == 'SOUTHERN OKLAHOMA DOCTORS COMMITTED TO TORT REFORM' | 
    ie$Spender == 'CALIFORNIA ACADEMY OF EYE PHYSICIANS & SURGEONS' |                           
    ie$Spender == 'CALIFORNIA ACADEMY OF OPHTHALMOLOGY' |                           
    ie$Spender == 'CALIFORNIA ASSOCIATION OF PSYCHIATRIC TECHNICIANS' |
    ie$Spender == 'CALIFORNIA MEDICAL ASSOCIATION' |     
    ie$Spender == 'COLORADO HEALTH CARE ASSOCIATION' |                       
    ie$Spender == 'COLORADO PHYSICAL THERAPY ASSOCIATION' |
    ie$Spender == 'COLORADO SOCIETY OF OSTEOPATHIC MEDICINE' |
    ie$Spender == 'CONNECTICUT PSYCHIATRICT SOCieTY' |
    ie$Spender == 'PEOPLE FOR A BETTER FLORIDA' |     
    ie$Spender == 'ALLIANCE FOR A BETTER FLORIDA' |     	        
    ie$Spender == 'HEALTHWATCH FLORIDA' |         
    ie$Spender == 'OUR ELDERS COUNT' |                              
    ie$Spender == 'CITIZENS FOR HONESTY IN POLITICS' |
    ie$Spender == 'CITIZENS FOR RESPONSIBLE GOVERNMENT' | 
    ie$Spender == 'LAST CHANCE FOR PATieNT CHOICE' |
    ie$Spender == 'PHYSICIANS TO PRESERVE THE WORKERS COMPENSATION SYSTEM IN IDAHO' |
    ie$Spender == 'MAINE MEDICAL ASSOCIATION' | 
    ie$Spender == 'CMTE FOR A HEALTHY FUTURE' |
    ie$Spender == 'MISSOURI ACADEMY OF FAMILY PHYSICIANS' |	
    ie$Spender == 'MISSOURI PHYSICAL THERAPY ASSOCIATION' |	
    ie$Spender == 'MISSOURI HOSPITAL ASSOCIATION' |	
    ie$Spender == 'MINNESOTA ONCOLOGY HEMATOLOGY' | # acc. to NIMSP they are registered lobbyist
    ie$Spender == 'MINNESOTA BUSINESS PARTNERSHIP' |
    ie$Spender == 'NORTHERN OHIO MEDICAL POLITICAL ACTION CMTE' |                   
    ie$Spender == 'OHIO SKILLED NURSING COALITION' |                  
    ie$Spender == 'OHIO PHARMACISTS ASSOCIATION' |
    ie$Spender == 'OKLAHOMA ASSOCIATION OF OPTOMETRIC PHYSICIANS' |                                    
    ie$Spender == 'TEXAS OPHTHALMOLOGICAL ASSOCIATION' |
    ie$Spender == 'TEXAS OPTOMETRIC ASSOCIATION' |  
    ie$Spender == 'TEXAS SPEECH-LANGUAGE-HEARING ASSOCIATION' |	
    ie$Spender == 'BORDER HEALTH' |
    ie$Spender == 'WASHINGTON STATE DENTAL ASSOCIATION' |
    ie$Spender == 'FRieNDS OF STEVENS HOSPITAL' |
    ie$Spender == 'WASHINGTON MEDICAL ASSOCIATION' |
    ie$Spender == 'WASHINGTON HEALTH CARE ASSOCIATION' |
    ie$Spender == 'WASHINGTON STATE MEDICAL ASSOCIATION'
  ] <- 'Single Issue' 

# Now those that were 'general business'
ie$source.type[
    ie$Spender == 'SITKA ECONOMIC DEVELOPMENT ASSOCIATION' |
    ie$Spender == 'GREATER PHOENIX CHAMBER OF COMMERCE' |
    ie$Spender == 'A STRONGER AMERICA MINNESOTA' |
    ie$Spender == 'MINNESOTA CHAMBER OF COMMERCE' |
    ie$Spender == 'TWINWEST CHAMBER OF COMMERCE' |
    ie$Spender == 'NATIONAL FEDERATION OF INDEPENDENT BUSINESS MINNESOTA SAVE AMERICAS FREE ENTERPRISE TRUST' |
    ie$Spender == 'PARTNERSHIP FOR OHIOS FUTURE' |
    ie$Spender == 'OHIO CHAMBER OF COMMERCE' |
    ie$Spender == 'OHIO MANUFACTURERS ASSOCIATION' |
    
    ie$Spender == 'ARIZONA CHAMBER OF COMMERCE' |
    ie$Spender == 'ARIZONA FARM BUREAU FEDERATION' |
    ie$Spender == 'BUSINESS LEADERS FOR MICHIGAN' |
    ie$Spender == 'MICHIGAN CHAMBER OF COMMERCE' |
    ie$Spender == 'MINNESOTA FORWARD' |
    ie$Spender == 'VOTE RACINO NOW COMMITTEE' |
    ie$Spender == 'PRO JOBS MAJORITY' |
    ie$Spender == 'BURNSVILLE CHAMBER' |
    ie$Spender == 'THE STATE CHAMBER OF OKLAHOMA' |
    ie$Spender == 'OKLAHOMA COUNCIL FOR ECONOMIC GROWTH' |
    ie$Spender == 'POINTE VISTA DEVELOPMENT' |
    ie$Spender == 'COLORADO SPRINGS CHAMBER OF COMMERCE' | #20
    
    ie$Spender == 'IRVINE CHAMBER OF COMMERCE' |
    ie$Spender == 'PARTNERSHIP FOR FLORIDAS FUTURE' |
    ie$Spender == 'CONSERVATIVE VALUES COALITION' |
    ie$Spender == 'COALITION FOR FLORIDA FAMILieS' |
    ie$Spender == 'TELL THE PUBLIC THE FACTS' |
    ie$Spender == 'FLORDIA JUSTICE REFORM GROUP' |
    ie$Spender == 'TEACHERS UNITED FOR BETTER SCHOOLS' |
    ie$Spender == 'NORTH FLORIDA LEADERSHIP COALITION' |
    ie$Spender == 'COALITION FOR BIPARTISAN PROGRESS' | #30
    ie$Spender == 'FLORIDIANS FOR DEMOCRATIC RESPONSIBILITY' |
    ie$Spender == 'BUSINESS LEADERS FOR A BETTER BOCA' |
    ie$Spender == 'IDAHO ASSOCIATION OF COMMERCE & INDUSTRY' |
    ie$Spender == 'BUSINESSES FOR BETTER GOVERNMENT' |
    ie$Spender == 'MISSOURI CHAMBER OF COMMERCE & INDUSTRY' |
    ie$Spender == 'TEXAS ASSOCIATION OF BUSINESS' |
    
    ie$Spender == 'CALIFORNIA CHAMBER OF COMMERCE' |                
    ie$Spender == 'OUTDOOR ADVERTISING ASSOCIATION OF CONNECTICUT' |
    ie$Spender == 'VOTERS RESPONSE' |
    ie$Spender == 'CMTE FOR A BETTER FLORIDA' | #40
    ie$Spender == 'RESPONSIBLE LEADERSHIP CMTE' |  
    ie$Spender == 'COALITION FOR REGIONAL EXCELLENCE IN LEADERSHIP' |
    ie$Spender == 'FLORIDIANS FOR ETHICS AND TRUTH IN POLITICS' |
    ie$Spender == 'CMTE FOR MORE MANUFACTURING JOBS' |
    ie$Spender == 'FLORIDA CITIZENS FOR CHANGE' |
    ie$Spender == 'US CHAMBER OF COMMERCE' |
    ie$Spender == 'MAINE PROSPERITY PROJECT' |
    ie$Spender == 'TEXAS CIVIL JUSTICE LEAGUE' |
    ie$Spender == 'TEXAS RESTAURANT ASSOCIATION' |
    ie$Spender == 'PEOPLE FOR JOBS' | #50
    ie$Spender == 'PENNSYLVANIA BEER ALLIANCE' | 
    
    ie$Spender == 'FLORIDA MAINSTREET MERCHANTS'  |
    ie$Spender == 'FLORIDIANS FOR CONSERVATIVE VALUES' |
    ie$Spender == 'CITIZENS FOR ETHICAL AND EFFECTIVE LEADERSHIP' |
    ie$Spender == 'CONSERVATIVE EDUCATION NETWORK' |  
    ie$Spender == 'CITIZENS FIRST' |                 
    ie$Spender == 'ALLIANCE FOR FLORIDAS FUTURE' |
    ie$Spender == 'REMEMBER THE LOTTERY' |
    ie$Spender == 'CITIZENS FOR SAFER STREETS' | 
    ie$Spender == 'PARTNERSHIP FOR FLORIDAS FUTURE' |
    ie$Spender == 'FLORIDIANS FOR EFFECTIVE LEADERSHIP IN GOVERNMENT' |
    ie$Spender == 'FLORIDIANS FOR TRUTH AND JUSTICE' |
    ie$Spender == 'FLORIDIANS FOR TRADITIONAL VALUES' |
    ie$Spender == 'FLORIDA CHAMBER OF COMMERCE ALLIANCE' |
    ie$Spender == 'OUR COMMUNITY DESERVES THE BEST' |
    ie$Spender == 'JUST REFORM' |
    ie$Spender == 'INTEGRITY COUNTS CMTE' |
    ie$Spender == 'INTEGRITY FOR OUR FAMILieS' |
    ie$Spender == 'COMMON SENSE COALITION'  |
    ie$Spender == 'PRESERVING FLORIDA FOR OUR CHILDREN' |
    ie$Spender == 'FLORIDA POLICY COUNCIL' |
    ie$Spender == 'SMALL BUSINESS SPEAKS' |
    ie$Spender == 'TEXAS RETAILERS ASSOCIATION' |
    ie$Spender == 'TEXANS FOR ECONOMIC DEVELOPMENT' |
    ie$Spender == 'CMTE FOR BALANCED STEWARDSHIP' |
    ie$Spender == 'WASHINGTON RESTAURANT ASSOCIATION' |
    ie$Spender == 'MAINE PROSPERITY PROJECT' | 
    ie$Spender == 'PRO SHORELINE' |
    ie$Spender == 'NATIONAL FEDERATION OF INDEPENDENT BUSINESS OHIO'
  ] <- 'Single Issue'

ie$source.type[
    ie$Spender == 'ROSS WESLEY BREWINGTON' |  # owner of Roscoe's signs
    ie$Spender == 'VANDERSLOOT, BELINDA & FRANK' |   # owns MELALEUCA
    ie$Spender == 'COULOMBE, PAUL' |  # owns white rock distilleries / liquor      	
    ie$Spender == 'PAUL PROUDIAN' |   # random local dude, hates one particular Republican
    ie$Spender == 'ZACHRY JR, H BARTELL' | # owns eponymous construction company (Texas construction mogul)
    ie$Spender == 'JOHN MIXON' |
    ie$Spender == 'LINNEHAN JR, JOHN D' | # President of Atlantic Acceptance Corp
    ie$Spender == 'ALLTUS, JANICE' | # Idaho citizen -- paid $404 for voter guide postage
    ie$Spender == 'LUNSFORD, JILL R' | # Idaho citizen -- paid $300 for newspaper ad
    ie$Spender == 'SPENCER, LARRY' | # Idaho 'citizen-activist'
    ie$Spender == 'AMORY, DANieL' | # Attorney in Maine
    ie$Spender == 'RHODA, RICHARD L' | # Attorney in Maine
    ie$Spender == 'FANKHAUSER, TERRY' | # Colorado farmer
    ie$Spender == 'DEBORAH KENT' | # Maine citizen (agriculture)
    ie$Spender == 'GARVEY, ERIN (EX DIR CALIFORNIANS FOR TECHNOLOGY & VIDEO CHOICE)' |
    ie$Spender == 'KELLER, CRAIG' | # uncoded
    ie$Spender == 'SYMMS, STEPHEN' | # uncoded
    ie$Spender == 'VANBUSKIRK, KENNETH A' | # uncoded
    ie$Spender == 'JOEL R STETKIS' | # uncoded
    ie$Spender == 'GREGORY A HOWARD' | # uncoded
    ie$Spender == 'FRANK WEATHERHEAD' | # uncoded
    ie$Spender == 'MACDONALD, JODY' | # uncoded
    ie$Spender == 'ELDIN L VILAFANE' | # uncoded
    ie$Spender == 'ELDIN L VILAFANE' | # uncoded
    ie$Spender == 'PAUL PETER NICOLAI' | # uncoded
    ie$Spender == 'EDWARD P KIRBY' | # uncoded
    ie$Spender == 'RAYMOND ROGERS' | # uncoded
    ie$Spender == 'WILLIAM KERRIGAN' | # uncoded
    ie$Spender == 'TOM BREUER' | # uncoded
    ie$Spender == 'TOM SHEILDS' | # uncoded
    ie$Spender == 'VAN DIEBERT, MARK' | # uncoded
    ie$Spender == 'HANSEN, SUSAN' | # uncoded
    ie$Spender == 'ZEMAN, MEREDITH' | # uncoded
    ie$Spender == 'RieDT, KENDRA' | # uncoded
    ie$Spender == 'KIRK, MAUREEN' | # uncoded
    ie$Spender == 'WITHERS, BETSY' | # uncoded
    ie$Spender == 'MAHER, KELLY' | # uncoded
    ie$Spender == 'WESTON, LIAM' | # uncoded
    ie$Spender == 'TODD' | # uncoded
    ie$Spender == 'ARMSTRONG, WILLIAM L' | # uncoded
    ie$Spender == 'COX, CHRIS W' | # uncoded
    ie$Spender == 'BROLLINI, DEBORAH' | # uncoded
    ie$Spender == 'SEYBERT, DANieL' | # uncoded
    ie$Spender == 'CULBERT, GREG T' | # uncoded
    ie$Spender == 'GRIFFIN, RANDY S' # uncoded
  ] <- 'Individual'

# Now identified corporations

ie$source.type[
    ie$Spender == 'W H PACIFIC' |
    ie$Spender == 'BREIER SCHEETZ PROPERTIES' |
    ie$Spender == 'DELOITTE & TOUCHE TEXAS' |
    ie$Spender == 'SHELBRAN CO & SHELBRAN INVESTMENTS' |
    ie$Spender == 'STOLAR PARTNERSHIP LLC' |
    ie$Spender == 'ENERGY HORIZONS TECHNOLOGIES'
  ] <- 'Corporation'

ie$source.type[ie$Sector1=='Party'] <- 'Party'

ie$source.type[
    ie$Sector1 == 'Candidate Contributions' |
    ie$Sector1 == 'Government Agencies/Education/Other' |
    ie$Sector1 == 'Non-Contributions' |
    ie$Spender == 'BRINKER INTERNATIONAL' # According to NIMSP this was 'in-kind' donation to state senator (catered meal)
  ] <- 'Other'


# this has to be the last line of this section!
ie$source.type[grep('PAC', ie$Spender)] <- 'PAC'
ie$source.type[grep('POLITICAL ACTION COMMITTEE', ie$Spender)] <- 'PAC'
ie$source.type[
    ie$Spender == 'JACOBS CARTER & BURGESS POLITICAL COMMITTEE' |
    ie$Spender == 'FARRIS MATHEWS BRANAN BOBANGO & HELLEN' |
    ie$Spender == 'MCCROSKEY LAW OFFICE' |
    ie$Spender == 'WORKING FAMILieS OF ALASKA'
  ] <- 'PAC'

ie$source.type[
  ie$Sector1=='Labor' &
    (ie$State=='AK' |
       ie$State=='AZ' |
       ie$State=='CO' |
       ie$State=='MI' |
       ie$State=='OH' |
       ie$State=='OK' |
       ie$State=='TX')] <- 'PAC'

##########################################################################################
##  CREATE STATE-LEVEL DATA FRAME BY BAN STATUS
##########################################################################################

state.map <- data.frame(state.name=state.name, ie.ban=NA, yr.ban=NA)

# No bans (0)
state.map$ie.ban[state.map$state.name=='Alabama'] <- 0
state.map$ie.ban[state.map$state.name=='Florida'] <- 0 # no ban, but only data is for ballot initiatives
state.map$ie.ban[state.map$state.name=='New Hampshire'] <- 0 # NH had ban, but abolished in 2000
state.map$ie.ban[state.map$state.name=='New York'] <- 0
state.map$ie.ban[state.map$state.name=='North Dakota'] <- 0

# Ban & we don't have data (1)
state.map$ie.ban[state.map$state.name=='Connecticut'] <- 1
state.map$ie.ban[state.map$state.name=='Kentucky'] <- 1
state.map$ie.ban[state.map$state.name=='Montana'] <- 1
state.map$ie.ban[state.map$state.name=='Pennsylvania'] <- 1
state.map$ie.ban[state.map$state.name=='South Dakota'] <- 1
state.map$ie.ban[state.map$state.name=='West Virginia'] <- 1
state.map$ie.ban[state.map$state.name=='Wisconsin'] <- 1
state.map$ie.ban[state.map$state.name=='Wyoming'] <- 1
state.map$ie.ban[state.map$state.name=='North Carolina'] <- 1

# Ban state that we have data for (2)
state.map$ie.ban[state.map$state.name=='Alaska'] <- 2
state.map$ie.ban[state.map$state.name=='Arizona'] <- 2
state.map$ie.ban[state.map$state.name=='Colorado'] <- 2
state.map$ie.ban[state.map$state.name=='Iowa'] <- 2
state.map$ie.ban[state.map$state.name=='Massachusetts'] <- 2
state.map$ie.ban[state.map$state.name=='Michigan'] <- 2
state.map$ie.ban[state.map$state.name=='Minnesota'] <- 2
state.map$ie.ban[state.map$state.name=='Ohio'] <- 2
state.map$ie.ban[state.map$state.name=='Oklahoma'] <- 2
state.map$ie.ban[state.map$state.name=='Tennessee'] <- 2
state.map$ie.ban[state.map$state.name=='Texas'] <- 2

# Control states for which we have data (3)
state.map$ie.ban[state.map$state.name=='California'] <- 3
state.map$ie.ban[state.map$state.name=='Idaho'] <- 3
state.map$ie.ban[state.map$state.name=='Maine'] <- 3
state.map$ie.ban[state.map$state.name=='Missouri'] <- 3
state.map$ie.ban[state.map$state.name=='Washington'] <- 3

state.map$yr.ban[state.map$state.name=='Alaska'] <- 1996
state.map$yr.ban[state.map$state.name=='Arizona'] <- 1978
state.map$yr.ban[state.map$state.name=='Colorado'] <- 2003
state.map$yr.ban[state.map$state.name=='Connecticut'] <- 2000
state.map$yr.ban[state.map$state.name=='Iowa'] <- 2003
state.map$yr.ban[state.map$state.name=='Kentucky'] <- 1974
state.map$yr.ban[state.map$state.name=='Massachusetts'] <- 1975
state.map$yr.ban[state.map$state.name=='Michigan'] <- 1976
state.map$yr.ban[state.map$state.name=='Minnesota'] <- 1988
state.map$yr.ban[state.map$state.name=='Montana'] <- 1947
state.map$yr.ban[state.map$state.name=='New Hampshire'] <- 1979
state.map$yr.ban[state.map$state.name=='North Carolina'] <- 1973
state.map$yr.ban[state.map$state.name=='Ohio'] <- 2005
state.map$yr.ban[state.map$state.name=='Oklahoma'] <- 2000
state.map$yr.ban[state.map$state.name=='Pennsylvania'] <- 1979
state.map$yr.ban[state.map$state.name=='South Dakota'] <- 2007
state.map$yr.ban[state.map$state.name=='Tennessee'] <- 1972
state.map$yr.ban[state.map$state.name=='Texas'] <- 1987
state.map$yr.ban[state.map$state.name=='West Virginia'] <- 1908
state.map$yr.ban[state.map$state.name=='Wisconsin'] <- 1905
state.map$yr.ban[state.map$state.name=='Wyoming'] <- 1977  

##########################################################################################

# save clean data
write.csv(ie, file='data/nimsp_ie_clean.csv', row.names=F)
write.csv(state.map, file='data/map_df.csv', row.names=F)

##########################################################################################
rm(list=ls())
##########################################################################################
#   END OF FILE
##########################################################################################