##########################################################################################

##  CITIZENS UNITED, STATES DIVIDED
##  AN EMPIRICAL ANALYSIS OF INDEPENDENT POLITICAL SPENDING

##  Indiana Law Journal, vol. 89, no. 1, pp. 315-372 (2014)

##  Replication code created by Doug Spencer
##  Contact: doug.spencer@law.uconn.edu

##  Last updated: March 1, 2015

##  Mac OSX 10.8.5
##  R version 3.1.2 ('Pumpkin Helmet')

##########################################################################################
## Library in required packages
##########################################################################################

library(foreign)
library(ggplot2)
library(xtable)
library(maps)
library(mapproj)
library(mapdata)
library(lmtest)
library(boot)
library(quantreg)

##########################################################################################
##	Read in data files
##########################################################################################

## Raw data cleaned using the 'data_clean.r' script

## Set working directory where data files are saved
setwd('~/Desktop/Doug/cusd_replication/')

ie <- read.csv('data/nimsp_ie_clean.csv', head=T, stringsAsFactors=F)
state <- read.csv('data/state_vars.csv', stringsAsFactors=FALSE, head=TRUE)
state.map <- read.csv('data/map_df.csv', stringsAsFactors=F, head=T)

##########################################################################################

##  FIGURES AND TABLES
#   (in order of presentation in paper)

##########################################################################################

#   TABLE 1: State independent expenditure bans

sortedBan <- state.map[order(state.map$yr.ban),]
sortedBan[1:21,c(1,3)]

##########################################################################################

#   FIGURE 1: Map of IE bans

#   States' corporate independent expenditure ban status at the time Citizens United
#   was decided. Shaded states had a ban. Diagonal stripes represent the states in
#   our sample. Note that data for Florida and North Carolina are also available, though
#   we exclude them from our sample.

proj.type <- 'albers'
proj.stdlats <- c(29.5, 45.5)
proj.orient <- c(90,-100,0)

# Map of lower 48
pdf(file='figures/figure_1_lower48.pdf', width=11, height=5.5)
par(mar=c(0,0,0,0))
map('state', proj=proj.type, par=proj.stdlats, orient=proj.orient, resolution=0, wrap=F, bound=T, col='black')
map('state', state.map$state.name[state.map$ie.ban==1], proj=proj.type, par=proj.stdlats,orient=proj.orient, fill=T, col='gray75', add=T)
map('state', state.map$state.name[state.map$ie.ban==2], proj=proj.type, par=proj.stdlats,orient=proj.orient, fill=T, col='gray75', add=T)
map('state', state.map$state.name[state.map$ie.ban==2], proj=proj.type, par=proj.stdlats,orient=proj.orient, fill=T, col='gray25', density=15, angle=45, add=T)
map('state', state.map$state.name[state.map$ie.ban==3], proj=proj.type, par=proj.stdlats,orient=proj.orient, fill=T, col='gray25', density=15, angle=45, add=T)
  legnames <- c('Ban on IEs', 'No Ban on IEs', 'Included in our sample')
  legcol <- c('gray65', 'white', 'gray25')
  legbord <- c('black', 'black', 'white')
  legangle <- c(0,0,45)
  legdens <- c(NA,0,30)
legend(0.1, -1.46, legnames, fill=legcol, border=legbord, angle=legangle, density=legdens, bty='n', cex=1)
dev.off()

# Map of Alaska

pdf(file='figures/figure_1_alaska.pdf', width=3.5, height=1.75)
par(mar=c(0,0,0,0))
map('world2Hires', 'USA:Alaska', projection='albers', parameters=c(55, 70), bound=T, fill=TRUE, col='gray75')
map('world2Hires', 'USA:Alaska', projection='albers', parameters=c(55, 70), bound=T, fill=TRUE, col='gray25', density=15, angle=45, add=T)
dev.off()

# Map of Hawaii

pdf(file='figures/figure_1_hawaii.pdf', width=3.5, height=1.75)
par(mar=c(0,0,0,0))
map('world2Hires', 'Hawaii', projection='albers', parameters=c(55, 70), fill=F, bound=T, col='black')
dev.off()

## Note: We cropped and combined the Lower 48 map with Alaska and Hawaii in Powerpoint

##########################################################################################

#   FIGURE 2: Difference-in-difference

#   Difference-in-differences between per capita independent expenditures in 2006
#   and 2010 and between states with a corporate independent expenditure ban and states
#   without a ban. This approach assumes a parallel time trend between treated states and control
#   states. The "treatment effect" or difference between spending in states in the treatment
#   condition and the hypothetical counterfactual is 18.8 cents per person.
#   Source: National Institute on Money in State Politics 2012. 

# Prepare variables for plot (we use per capita spending here)
df <- merge(ie[ie$elec.year!=2008,], state, by.x=c('State', 'elec.year'), by.y=c('state', 'year'))

# Aggregate spending
spend <- aggregate(Amount~ban+elec.year, data=df, FUN=sum)
spend <- subset(spend, spend$elec.year!=2008)

# Aggregate population
pop <- state[state$year!=2008 & state$state!='MO' & state$state!='NC',]
pop$ban <- ifelse(pop$state=='AK' | pop$state=='AZ' | pop$state=='CO' | pop$state=='IA' | pop$state=='MA' | 
                    pop$state=='MI' | pop$state=='MN' | pop$state=='OH' | pop$state=='OK' | pop$state=='TN' | pop$state=='TX', 1, 0)
pop.total <- aggregate(state.pop~ban+year, data=pop, FUN=sum)

diff <- cbind(spend, pop.total$state.pop)
names(diff) <- c('ban', 'year', 'amount', 'state.pop')
diff$pop.amt <- diff$amount/diff$state.pop

cont.pre <- diff$pop.amt[diff$year==2006 & diff$ban==0]
cont.post <- diff$pop.amt[diff$year==2010 & diff$ban==0]
treat.pre <- diff$pop.amt[diff$year==2006 & diff$ban==1]
treat.post <- diff$pop.amt[diff$year==2010 & diff$ban==1]
counterfact <- treat.pre-(cont.pre-cont.post)

# Now the plot

pdf('figures/figure_2_diff.pdf', width=5.75, height=4)

par(mar=c(3,3,0,0), mgp=c(1.75,0.5,0))
plot(diff$year, diff$pop.amt, type='n', axes=F, xlab='Year', ylab='IEs per capita', ylim=c(0.45,0.9), xlim=c(2005.5,2010.8), cex.lab=0.8)
axis(1, at=c(2006, 2010), cex.axis=0.8)
axis(2, at=c(0.45,.55,.65,.75,.85), cex.axis=0.8)

segments(x0=2010.1, x1=2010.1, y0=counterfact, y1=treat.post, col='black', lwd=2)
segments(x0=2010, x1=2010.1, y0=treat.post, y1=treat.post, col='black', lwd=2)
segments(x0=2010, x1=2010.1, y0=counterfact, y1=counterfact, col='black', lwd=2)

segments(x0=2006, y0=cont.pre, x1=2010, y1=cont.post, lty=1, lwd=1.5)
segments(x0=2006, y0=treat.pre, x1=2010, y1=treat.post, lty=1, lwd=4)
segments(x0=2006, y0=treat.pre, x1=2010, y1=counterfact, lty=2, col='gray45')

points(x=2006, y=cont.pre, pch=19)
points(x=2010, y=cont.post, pch=19)
points(x=2006, y=treat.pre, pch=19)
points(x=2010, y=treat.post, pch=19)
points(x=2010, y=counterfact, pch=19, col='white')
points(x=2010, y=counterfact, pch=1, col='black')

text(2007, .75, 'IE spending in states \n with no ban', cex=0.8)
text(2008, .85, 'IE spending in states with ban', cex=0.8)
text(2009.5, 0.55, 'Counterfactual IE spending', cex=0.75, col='gray45')

arrows(x0=2007, y0=0.72, x1=2007, y1=0.655, length=0.1, angle=15, lwd=1.25)
arrows(x0=2008, y0=0.83, x1=2009, y1=0.78, length=0.1, angle=15, lwd=1.25)
arrows(x0=2009.4, y0=.57, x1=2009.15, y1=.63, length=0.1, angle=15, lwd=1.25, lty=2, col='gray45')

text(2010.52, 0.78, 'Treatment', cex=0.8, col='black')
text(2010.5, 0.755, expression(paste('effect (',beta,')')), cex=0.8, col='black')

dev.off()

# Treatment effect
treat.effect <- treat.post-counterfact # == 0.1878984 cents (see Figure 2 caption on p. 343)
treat.pct <- treat.effect/counterfact # == 0.2780005

##########################################################################################

#   TABLE 2: Difference-in-differences modeled

#   Note: One observation per state-year (N = 32). Model (A) represents a simple OLS
#   interaction model with no control variables. In model (B) we include the following
#   covariates: Democratic percentage of state lower house, number of contested seats in the
#   current election, lagged turnover rates in lower house, state median income, and state
#   population. Due to our low statistical power for this part of the analysis, these models are not
#   statistically significant.

df <- merge(ie[ie$elec.year!=2008,], state, by.x=c('State', 'elec.year'), by.y=c('state', 'year'))
df.1 <- state[state$year!=2008 & state$state!='NC' & state$state!='FL',]
df.2 <- aggregate(Amount~ban+elec.year+State, data=df, FUN=sum)
df.3 <- merge(df.2, state, by.x=c('State', 'elec.year'), by.y=c('state', 'year'))
df.3$ban <- rep(0, dim(df.3)[1])
df.3$ban <- ifelse(df.3$State=='AK' | df.3$State=='AZ' | df.3$State=='CO' | df.3$State=='IA' | df.3$State=='MA' | 
                     df.3$State=='MI' | df.3$State=='MN' | df.3$State=='OH' | df.3$State=='OK' | df.3$State=='TN' | 
                     df.3$State=='TX', 1, 0)
df.3$prepost <- ifelse(df.3$elec.year==2010,1,0)

# Run OLS models (we use log IE here)
dd.out.1 <- lm(log(Amount) ~ prepost + ban + I(prepost*ban), data=df.3)
dd.out.2 <- lm(log(Amount) ~ prepost + ban + I(prepost*ban) + PercDemLH + lagged.LH.turnover + LH.contest + 
                 median.income + state.pop, data=df.3)

summary(dd.out.1)
summary(dd.out.2)

# Cluster SEs by state
clx <- function(dat,fm, cluster){
  require(sandwich, quietly = TRUE)
  require(lmtest, quietly = TRUE)
  M <- length(unique(cluster))
  N <- length(cluster)
  K <- fm$rank
  dfc <- (M/(M-1))*((N-1)/(N-K))
  uj  <- apply(estfun(fm),2, function(x) tapply(x, cluster, sum));
  vcovCL <- dfc*sandwich(fm, meat=crossprod(uj)/N)
  coeftest(fm, vcovCL)
}

# compare to clustered SEs
dd.1.clx <- clx(df.3, dd.out.1, df.3$State)
dd.2.clx <- clx(df.3, dd.out.2, df.3$State)

# bootstrap SEs

boot.fn.1=function(data, index){
  return(coef(lm(log(Amount) ~ prepost + ban + I(prepost*ban), data=data, subset=index))[2:4])
}
boot.fn.2=function(data, index){
  return(coef(lm(log(Amount) ~ prepost + ban + I(prepost*ban) + PercDemLH + lagged.LH.turnover + 
                   LH.contest + median.income + state.pop, data=data, subset=index))[2:4])
}

set.seed(1979)
boot.1 <- boot(data=df.3, statistic=boot.fn.1, R=10000)
boot.2 <- boot(data=df.3, statistic=boot.fn.2, R=10000)

coef.1 <- sapply(as.data.frame(boot.1$t), quantile, probs=c(0.025, 0.975), na.rm=T)
coef.2 <- sapply(as.data.frame(boot.2$t), quantile, probs=c(0.025, 0.975), na.rm=T)

table.2 <- data.frame(
  coef.name = rep(c('Pre-post', 'ban', 'Interaction'),2),
  coef = c(coef(dd.out.1)[2:4], coef(dd.out.2)[2:4]),
  lower = c(coef.1[1,], coef.2[1,]),
  upper = c(coef.1[2,], coef.2[2,]),
  model = c(rep('No Controls', 3), rep('With Controls', 3)))

table.2 # see Table 2 on p. 345

# We did not set.seed() for the bootstrap values reported in the paper, 
# so the values reported here are slightly different.

##########################################################################################

#   FIGURE 3: Raw independent expenditures (IE), in millions of dollars, by spender.

#   We exclude spending by individuals (three-tenths of 1% of spending) and spending
#   categorized as "Other" (four-tenths of 1%) by NIMSP. The largest category of 
#   spending is coded by the NIMSP as "Single Issue" and comprises spending by both 
#   501(c) organizations and 527 political committees. 


# Create vector of annual proportion of spending by source.type
agg.spend <- aggregate(Amount~elec.year+ban+source.type, data=ie[ie$source.type>0 & ie$Amount>0 & ie$race.type!='Ballot Initiative' & ie$elec.year!=2008,], FUN=sum)

# Subset out individuals and others (combined 7/10 of 1% of spending)
agg.spend <- agg.spend[agg.spend$source.type!='Individual' & agg.spend$source.type!='Other',]

# Order variables
agg.spend$type <- 0
agg.spend$type[agg.spend$source.type=='Corporation'] <- 1
agg.spend$type[agg.spend$source.type=='Labor'] <- 2
agg.spend$type[agg.spend$source.type=='PAC'] <- 3
agg.spend$type[agg.spend$source.type=='Party'] <- 4
agg.spend$type[agg.spend$source.type=='Single Issue'] <- 5

agg.spend$type <- as.factor(agg.spend$type)
levels(agg.spend$type) <- c('Corporation', 'Labor', 'PAC', 'Party', '501c & 527')
agg.spend$Ban <- as.factor(agg.spend$ban); levels(agg.spend$Ban) <- c('Control', 'Treated')

# Scale spending in the millions
agg.spend$amt.mil <- agg.spend$Amount/1000000

p.spendtype <- ggplot(agg.spend, aes(x=elec.year, y=amt.mil, fill=type)) + 
  geom_bar(stat='identity') + coord_flip() + facet_grid(Ban~.) +
  scale_y_continuous('ie Amount (in millions)', breaks=c(0, 20, 40, 60)) +
  scale_x_continuous('Year', breaks=c(2006,2010)) +
  scale_fill_manual('Sector', values=c('Corporation'='gray95', 'Labor'='gray85', 'Party'='gray40', '501c & 527'='black', 'PAC'='gray70')) +
  theme(panel.background=element_rect(fill = 'white', colour = 'black')) +
  theme(axis.text.x=element_text(size=11), axis.text.y=element_text(size=11))

pdf('figures/figure_3_sector.pdf', width=5.5, height=3)
print(p.spendtype)
dev.off()

##########################################################################################

#   FIGURE 4: Logged amount spent by each unique spender in 2006 and 2010.

#   Logged amounts are "translated" into dollar amounts in parenthesis. The data include
#   843 reported spenders from sixteen states. Note that reported spenders are simply those
#   that report independent expenditures pursuant to campaign finance requirements, and 
#   these reported spenders could all be spending money received by the same "root" spender 
#   or donor, which goes unreported. 

amt.spend <- aggregate(ie$Amount, by=list(ie$State, ie$elec.year, ie$Spender), FUN=sum)
colnames(amt.spend) <- c('State', 'Year', 'Spender', 'amt.spend')
x <- merge(ie, amt.spend, by = c('State', 'Year', 'Spender'), all.x = T, all.y = T)

a <- x[order(x$State, x$Year, x$Spender),]
a$PostCU <- as.numeric(a$Year==2010)
drop <- NA
a <- a[complete.cases(a$Year),]

for(i in 2:length(a$State)){
  if(a$Year[i] == a$Year[i-1]){
    drop[i] <- as.numeric(a$Spender[i] == a$Spender[i-1])
  }
}
a <- a[drop != 1,]
a <- a[complete.cases(a$State, a$elec.year, a$amt.spend),]

pdf(file='figures/figure_4_density.pdf', width=6, height=5.1)
par(mar=c(3,4,3,3))
plot(density(log(a$amt.spend)), main='', xaxt = 'n', xlab = '', axes=F, ylim=c(0, .145))
axis(side = 1, at = c(5, 10, 15), labels = c("5 \n (~ $150)", "10 \n (~ $22000)", "15 \n (~$3.3 m)"), 
     tcl = NA, cex.axis = 0.8)
axis(2, at=c(0, .02,.04,.06,.08,.1,.12,.14), cex.axis=0.8)
box()
dev.off()

##########################################################################################

#   FIGURE 5: Quantile-quantile plot for treatment and control states between 2006 and 2010.

#   Each dataset (treatment and control) are broken into 100 equally sized quantiles, or
#   percentiles. Circles represent percentiles in control states and Xs represent percentiles
#   in treatment states. The 45° line represents equal spending in 2006 and 2010. 

pdf(file='figures/figure_5_qqplot.pdf', height=4.5, width=6.5)

  par(mgp=c(1.8, 0.4, 0), mar=c(3,3,3,3))
  qqplot(log(a$amt.spend[a$Year == 2006 & a$ban == 0]), log(a$amt.spend[a$Year == 2010 & a$ban == 0]), col = "black", 
       main = '', ylim = c(0, 16), xlim = c(0, 16), ylab = "", xlab = "", pch=1, cex=0.8, cex.axis=0.8, cex.lab=0.8)
  par(new = T)
  qqplot(log(a$amt.spend[a$Year == 2006 & a$ban == 1]), log(a$amt.spend[a$Year == 2010 & a$ban == 1]), 
       col = 'gray', ylim = c(0, 16), xlim = c(0, 16), ylab = 'Log spending, 2010', xlab = 'Log spending, 2006', pch=4, cex=0.8, cex.axis=0.8, cex.lab=0.8)
  abline(0,1)
  legend(11,5,legend=c('Treated states', 'Control states'), pch=c(4,1), col=c('gray', 'black'), bty='n', cex=0.8)

dev.off()

##########################################################################################

#   FIGURE 6: Quantile regression (on 100 quantiles) by control and treated states

#   Each dot is the difference between spending in that percentile for 2010 and spending
#   in that percentile for 2006 in both treatment and control states. The grey region is a
#   95% confidence interval. Models includde state fixed effects.

t <- a[a$ban == 1 & a$elec.year!=2008,]
c <- a[a$ban == 0 & a$elec.year!=2008,]

fit.t <- rq(log(t$amt.spend) ~  t$PostCU + I(t$State), tau = seq(from=0.01, to=0.99, by=0.01))
fit.c <- rq(log(c$amt.spend) ~  c$PostCU + I(c$State), tau = seq(from=0.01, to=0.99, by=0.01))

df.treat <- data.frame(quant=fit.t$tau, est=fit.t$coefficients[2,], lower=NA, upper=NA)
tau.t <- fit.t$tau

df.cont <- data.frame(quant=fit.c$tau, est=fit.c$coefficients[2,], lower=NA, upper=NA)
tau.c <- fit.c$tau

for (i in 1:length(tau.t)){
  sub <- summary(fit.t)[[i]]
  df.treat[i,3] <- sub$coefficients[2,2]
  df.treat[i,4] <- sub$coefficients[2,3]
}

for (i in 1:length(tau.c)){
  sub <- summary(fit.c)[[i]]
  df.cont[i,3] <- sub$coefficients[2,2]
  df.cont[i,4] <- sub$coefficients[2,3]
}

# polygon objects
X.Vec.T <- c(min(df.treat$quant), sort(df.treat$quant), max(df.treat$quant), rev(sort(df.treat$quant)))
Y.Vec.T <- c(df.treat$lower[1], df.treat$lower, df.treat$upper[99], rev(df.treat$upper))
X.Vec.C <- c(min(df.cont$quant), sort(df.cont$quant), max(df.cont$quant), rev(sort(df.cont$quant)))
Y.Vec.C <- c(df.cont$lower[1], df.cont$lower, df.cont$upper[99], rev(df.cont$upper))

# treatment plot
quant.T <- qplot(df.treat$quant, df.treat$est) + 
  geom_polygon(aes(X.Vec.T, Y.Vec.T), fill="gray") + geom_path(colour="white") +
  geom_hline(yintercept=0, size=0.7) + geom_point() +
  ggtitle('Treated States') +
  scale_y_continuous('', limits=c(-1.5, 2.5), breaks=NULL) +
  scale_x_continuous('Quantiles', breaks=seq(0,1,0.1)) +
  theme(panel.background=element_rect(fill = "white", colour = "black")) +
  theme(axis.text.x=element_text(size=11), axis.text.y=element_text(size=11))  # +

# control plot
quant.C <- qplot(df.cont$quant, df.cont$est) + 
  geom_polygon(aes(X.Vec.C, Y.Vec.C), fill='gray') + geom_path(colour='white') +
  geom_hline(yintercept=0, size=0.7) + geom_point() +
  ggtitle('Control States') +
  scale_y_continuous(expression(paste(Delta, " log IE spending (2010 minus 2006)")), limits=c(-1.5, 2.5), breaks=c(-1.5,-1, -.5, 0, 0.5, 1, 1.5, 2, 2.5)) +
  scale_x_continuous("Quantiles", breaks=seq(0,1,0.1)) +
  theme(panel.background=element_rect(fill = "white", colour = "black")) +
  theme(axis.text.x=element_text(size=11), axis.text.y=element_text(size=11)) # +

# Multiplot function for displaying multiple plots in grid
# from 'Cookbook for R'
multiplot <- function(..., plotlist=NULL, cols) {
  require(grid)
  
  # Make a list from the ... arguments and plotlist
  plots <- c(list(...), plotlist)
  
  numPlots = length(plots)
  
  # Make the panel
  plotCols = cols                       # Number of columns of plots
  plotRows = ceiling(numPlots/plotCols) # Number of rows needed, calculated from # of cols
  # Set up the page
  grid.newpage()
  pushViewport(viewport(layout = grid.layout(plotRows, plotCols)))
  vplayout <- function(x, y)
    viewport(layout.pos.row = x, layout.pos.col = y)
  # Make each plot, in the correct location
  for (i in 1:numPlots) {
    curRow = ceiling(i/plotCols)
    curCol = (i-1) %% plotCols + 1
    print(plots[[i]], vp = vplayout(curRow, curCol ))
  }
  
}

pdf(file='figures/figure_6_quantreg.pdf', height=6, width=11)
multiplot(quant.C, quant.T, cols=2)
dev.off()

##########################################################################################
##########################################################################################
##########################################################################################

##    APPENDIX

##########################################################################################
##########################################################################################
##########################################################################################

#   FIGURE B: Independent expenditures during the 2010 election cycle.

#   The vertical dashed line represents July 1, 2010, when every state in the sample
#   had repealed its ban on corporate independent expenditures. In the “treated” states, 
#   89.8% of all independent expenditures happened after July 1. This is a lower bound, 
#   since many of the states repealed their bans much earlier than July 1. Aggregated 
#   independent expenditures after the date of each individual state’s repeal accounted 
#   for 96.4% of all independent expenditures in the 2010 election cycle (and 100% in 
#   seven of the eleven treated states).

ie.date <- subset(ie, nchar(ie$Date) > 4 & ie$race.type!='Judicial' & ie$race.type!='Ballot Initiative' & ie$race.type!='State Legislature')
ie.date$dd <- as.POSIXct(strptime(ie.date$Date, format='%m/%d/%y'))

ie.df <- subset(ie.date, ie.date$Year > 2006 & ie.date$Year < 2011)

ie.agg <- aggregate(Amount~dd+ban+race.type, data=ie.df, FUN=sum)
ie.agg$ban <- as.factor(ie.agg$ban)
levels(ie.agg$ban) <- c('Control', 'Treated')

ie.agg$race.type <- gsub('Governor/Lieutenant Governor', replacement='Governor', ie.agg$race.type)

plot.b <- qplot(dd, Amount, data=ie.agg, geom='line', facets=race.type~ban, xlab='Date', ylab='IE Amount') +
  geom_vline(xintercept=as.numeric(ie.agg$dd[121]), colour='black', linetype=2, size=0.4) +
  scale_y_continuous(breaks=c(0,2000000,4000000,6000000,8000000), labels=c('0', '2 mil', '4 mil', '6 mil', '8 mil')) +
  theme(panel.background=element_rect(fill='white', colour='black'),
        strip.text.y=element_text(size=10, angle=-90),
        strip.text.x=element_text(size=10, angle=0),
        axis.text.x=element_text(colour='grey50', size=7.5, angle=0),
        axis.text.y=element_text(colour='grey50', size=7.5),
        strip.background=element_rect(fill='white', colour='white'))

pdf(file='figures/figure_appendix_b.pdf', width=7, height=5)
print(plot.b)
dev.off()

##########################################################################################

#   FIGURE D: Quantile difference-in-differences

#   Plot of regression interaction term including state fixed effects. 
#   The [treatment–control] difference at every percentile is shown, comprising the
#   [2010–2006] difference in log independent expenditures by spender state and year.
#   The gray region is the 95% confidence interval. 

## quantile regression
fit1 <- rq(log(a$amt.spend) ~ a$ban + a$PostCU + I(a$ban*a$PostCU), seq(from=0.01, to=0.99, by=0.01))
df.all <- data.frame(quant=fit1$tau, est=fit1$coefficients[4,], lower=NA, upper=NA)
tau.A <- fit1$tau

for (i in 1:length(tau.A)){
  sub <- summary(fit1)[[i]]
  df.all[i,3] <- df.all[i,2] - abs(1.96*(sub$coefficients[4,2]))
  df.all[i,4] <- df.all[i,2] + abs(1.96*(sub$coefficients[4,2]))
}

# create objects for polygon
X.Vec.A <- c(min(df.all$quant), df.all$quant, max(df.all$quant), rev(df.all$quant))
Y.Vec.A <- c(df.all$lower[1], df.all$lower, df.all$upper[99], rev(df.all$upper))

# now the plot
quant.all <- qplot(df.all$quant, df.all$est) +
  geom_polygon(aes(X.Vec.A, Y.Vec.A), fill="gray") + geom_path(colour="white") +
  geom_hline(yintercept=0, size=0.7) + geom_point() +
  scale_y_continuous(expression(paste(Delta," Treated IEs - ",Delta," Control IEs (logged)")), 
                     limits=c(-2.05, 3), breaks=seq(-2,3,1)) +
  scale_x_continuous("Quantiles", breaks=seq(0,1,0.2)) +
  theme(panel.background=element_rect(fill = "white", colour = "black")) +
  theme(axis.text.x=element_text(size=11), axis.text.y=element_text(size=11))

pdf(file='figures/appendix_figure_d.pdf', height=6, width=8)
print(quant.all)
dev.off()

##########################################################################################

#   FIGURE E

#   Quantile-quantile plots for “repeat players” in treatment and control states
#   between 2006 and 2010. Circles are the QQplot for the control states (N = 51), and
#   Xs are the QQplot for treatment states (N = 42). The diagonal line is where the points
#   would be if spending in 2006 exactly equaled the spending in 2010 for a group. 

##########################################################################################

#   FIGURE F

#   Direct campaign contributions to gubernatorial candidates in states that passed a
#   ban on corporate/union independent expenditures.

#   Source: Thad Beyle & Jennifer M. Jensen, Gubernatorial Campaign Expenditures Database,
#   http://www.unc.edu/~beyle/guber.html.

#   Note: If there is a substitution away from independent expenditures in reaction to a ban, then
#   we expect to see more contributions in years following a ban. In most states, only individuals
#   are allowed to substitute in this way; corporations and unions are banned in twenty-three
#   states from making direct contributions to candidates. See Life After Citizens United, National
#   Conference of State Legislatures, http://www.ncsl.org/legislatures-elections/elections/
#   citizens-united-and-the-states.aspx (updated Jan. 4, 2011).

rm(list=ls())

df <- read.csv(file='data/beyle.csv', stringsAsFactors=F, head=T)
x <- aggregate(log(TotSpend)~YrSinceBan, data=df, FUN=mean)
names(x) <- c('YrSinceBan', 'TotSpend')

yr.plot <- qplot(YrSinceBan, log(TotSpend), data=df, geom='smooth', se=F, col='gray') + geom_point(col='lightgray', pch=4) + 
  geom_vline(xintercept=0, linetype=2, colour='gray') + geom_point(data=x, aes(x=YrSinceBan, y=TotSpend), col='black', size=3) +
  scale_y_continuous('Contributions to gubernatorial candidates (logged)', limits=c(12, 18), breaks=seq(12,18,2)) +
  scale_x_continuous('Year from IE ban', limits=c(-5,5), breaks=seq(-5,5,1)) +
  scale_color_manual(values=c('gray30'), guide='none') +
  theme(panel.background=element_rect(fill = 'white', colour = 'black')) +
  theme(axis.text.x=element_text(size=10), axis.text.y=element_text(size=10))

pdf(file='figures/appendix_figure_f.pdf', height=5.5, width=6.5)
print(yr.plot)
dev.off()

##########################################################################################
#   END OF FILE
##########################################################################################